# frozen_string_literal: false
require_relative 'device_name_generated'

module Devices
  include DeviceNameGenerated
  extend self

  def pascal_device_name
    {
      BlackberryPlayBook: 'Devices::Blackberry_PlayBook'.freeze,
      BlackBerryZ30: 'Devices::BlackBerry_Z30'.freeze,
      GalaxyA5: 'Devices::Galaxy_A5'.freeze,
      GalaxyNote10: 'Devices::Galaxy_Note_10'.freeze,
      GalaxyNote10Plus: 'Devices::Galaxy_Note_10_Plus'.freeze,
      GalaxyNote2: 'Devices::Galaxy_Note_2'.freeze,
      GalaxyNote3: 'Devices::Galaxy_Note_3'.freeze,
      GalaxyNote4: 'Devices::Galaxy_Note_4'.freeze,

      GalaxyNote9: 'Devices::Galaxy_Note_9'.freeze,
      GalaxyS3: 'Devices::Galaxy_S3'.freeze,
      GalaxyS5: 'Devices::Galaxy_S5'.freeze,

      GalaxyS9: 'Devices::Galaxy_S9'.freeze,
      GalaxyS9Plus: 'Devices::Galaxy_S9_Plus'.freeze,
      GalaxyS10: 'Devices::Galaxy_S10'.freeze,
      GalaxyS10Plus: 'Devices::Galaxy_S10_Plus'.freeze,
      GalaxyS20: 'Devices::Galaxy_S20'.freeze,
      # IPad: 'Devices::IPad'.freeze,
      IPad6thGen: 'Devices::IPad_6th_Gen'.freeze,
      IPad7thGen: 'Devices::IPad_7th_Gen'.freeze,
      IPadAir2: 'Devices::IPad_Air_2'.freeze,
      IPadMini: 'Devices::IPad_Mini'.freeze,
      IPadPro: 'Devices::IPad_Pro'.freeze,
      IPhone11: 'Devices::IPhone_11'.freeze,
      IPhone11Pro: 'Devices::IPhone_11_Pro'.freeze,
      IPhone11ProMax: 'Devices::IPhone_11_Pro_Max'.freeze,
      IPhone4: 'Devices::IPhone_4'.freeze,
      IPhone5SE: 'Devices::IPhone_5SE'.freeze,
      IPhone678: 'Devices::IPhone_6_7_8'.freeze,
      IPhone678Plus: 'Devices::IPhone_6_7_8_Plus'.freeze,
      IPhoneX: 'Devices::IPhone_X'.freeze,
      IPhoneXR: 'Devices::IPhone_XR'.freeze,
      IPhoneXS: 'Devices::IPhone_XS'.freeze,
      IPhoneXSMax: 'Devices::IPhone_XS_Max'.freeze,

      KindleFireHDX: 'Devices::Kindle_Fire_HDX'.freeze,
      LaptopWithHIDPIScreen: 'Devices::Laptop_with_HiDPI_screen'.freeze,
      LaptopWithMDPIScreen: 'Devices::Laptop_with_MDPI_screen'.freeze,
      LaptopWithTouch: 'Devices::Laptop_with_touch'.freeze,
      LGG6: 'Devices::LG_G6'.freeze,
      LGOptimusL70: 'Devices::LG_Optimus_L70'.freeze,
      MicrosoftLumia550: 'Devices::Microsoft_Lumia_550'.freeze,
      MicrosoftLumia950: 'Devices::Microsoft_Lumia_950'.freeze,
      Nexus10: 'Devices::Nexus_10'.freeze,
      Nexus4: 'Devices::Nexus_4'.freeze,
      Nexus5: 'Devices::Nexus_5'.freeze,
      Nexus5X: 'Devices::Nexus_5X'.freeze,
      Nexus6: 'Devices::Nexus_6'.freeze,
      Nexus6P: 'Devices::Nexus_6P'.freeze,
      Nexus7: 'Devices::Nexus_7'.freeze,

      NokiaLumia520: 'Devices::Nokia_Lumia_520'.freeze,
      NokiaN9: 'Devices::Nokia_N9'.freeze,
      OnePlus7T: 'Devices::OnePlus_7T'.freeze,
      OnePlus7TPro: 'Devices::OnePlus_7T_Pro'.freeze,

      Pixel2: 'Devices::Pixel_2'.freeze,
      Pixel2XL: 'Devices::Pixel_2_XL'.freeze,
      Pixel3: 'Devices::Pixel_3'.freeze,
      Pixel3XL: 'Devices::Pixel_3_XL'.freeze,
      Pixel4: 'Devices::Pixel_4'.freeze,
      Pixel4XL: 'Devices::Pixel_4_XL'.freeze,
      Pixel5: 'Devices::Pixel_5'.freeze,
      GalaxyS22: 'Devices::Galaxy_S22'.freeze,
      GalaxyTabS7: 'Devices::Galaxy_Tab_S7'.freeze,
    }
  end

  # looks like this was added here by mistake by https://trello.com/c/M1YiwtHb
  # so as it not work, then can be ignored
  # def support_drop_for_device_name
  #   {
  #     IPhone14: 'iPhone 14'.freeze,
  #     IPhone14ProMax: 'iPhone 14 Pro Max'.freeze,
  #   }
  # end

  # looks like this was added here by mistake by https://trello.com/c/SZAPDKSI
  # so as it not work, then can be ignored
  # def unsupported_devices_from_android12
  #   {
  #     XiaomiRedmiNote11: 'Xiaomi Redmi Note 11'.freeze,
  #     XiaomiRedmiNote11Pro: 'Xiaomi Redmi Note 11 Pro'.freeze,
  #     Pixel6: 'Pixel 6'.freeze,
  #     GalaxyS22Plus: 'Galaxy S22 Plus'.freeze,
  #     GalaxyTabS8: 'Galaxy Tab S8'.freeze
  #   }
  # end

  def const_missing(name)
    if pascal_device_name.include?(name)
      # deprecate_constant :... not allow to point to new version (
      puts "Warning: constant Devices::#{name} is deprecated use #{pascal_device_name[name]} instead."
      const_get(pascal_device_name[name])
    else
      super
    end
  end

  # now actual enum_values are in generated file
end
